credential_env_vars_for_deployment

Function credential_env_vars_for_deployment 

pub const fn credential_env_vars_for_deployment(
    deployment: LighterDeployment,
    environment: LighterEnvironment,
) -> (&'static str, &'static str, &'static str)
Environment variable names for credentials on a Lighter protocol deployment.

Returns (api_key_index_var, api_secret_var, account_index_var). The deployment and environment select an independent credential namespace.